@@ -5,6 +5,7 @@
 #pragma once
 
 #include <KContacts/PhoneNumber>
+#include <KPeople/PersonsModel>
 #include <QObject>
 
 #include "contactutilsinterface.h"
@@ -19,7 +20,14 @@ public:
 
     Q_INVOKABLE QString displayString(const QString &contact);
     Q_INVOKABLE QVariantList phoneNumbers(const QString &kPeopleUri);
+    Q_INVOKABLE QString phoneNumberToContactUri(const QString &phoneNumber);
+    Q_INVOKABLE QString photoImageProviderUri(const QString &contactUri);
     bool isValid() const;
+
 Q_SIGNALS:
     void isValidChanged();
+
+private:
+    QList<KContacts::PhoneNumber> internalPhoneNumbers(const QString &kPeopleUri) const;
+    QString numericOnlyString(QString str) const;
 };
